@@ -4,9 +4,13 @@ use 5.006002;
 use strict;
 use warnings;
 
-our $VERSION = '1.018';
+our $VERSION = '1.019';
 
-my %introduces = ( '5.032' => [qw[
+my %introduces = do { no warnings 'qw';
+                 ( '5.034' => [qw[
+                                 {,n} 0o blanks-in-curlies
+                             ]],
+                   '5.032' => [qw[
                                   unicode13.0 chained-comparisons
                                   unicode-identifier-status
                                   unicode-name-property
@@ -51,7 +55,7 @@ my %introduces = ( '5.032' => [qw[
                                  // ?PARNO ?<> ?| quant+ regex-verbs
                                  \K \R \v \h \gN readline()
                                  stack-file-test recursive-sort /p
-                                 lexical-$_
+                                 lexical-$_ pack<
                               ]],
                    '5.008001' => [qw[
                                  s-utf8-delimiters-hack
@@ -59,7 +63,7 @@ my %introduces = ( '5.032' => [qw[
                    old => [qw[
                                  ?? for-qw @_=split
                           ]],
-                 );
+                 )};
 
 my %removed = ( 'auto-deref'             => '5.024',
                 'lexical-$_'             => '5.024',
@@ -77,6 +81,7 @@ my %alias = (
     '\V' => '\v',
     'defined-or' => '//',
     'lexical-default-variable' => 'lexical-$_',
+    'pack-byte-order-modifiers' => 'pack<',
     'readline-argv' => 'readline()',
     'regex-generic-linebreak' => '\R',
     'regex-horizontal-whitespace' => '\h',
@@ -151,6 +156,9 @@ my %alias = (
     # 5.032
     'unicode-13.0' => 'unicode13.0',
     'unicode-identifier-type' => 'unicode-identifier-status',
+    # 5.034
+    'empty-left-quantifier' => '{,n}',
+    'octal-literals' => '0o',
 );
 
 my %_introduced = map {
@@ -256,7 +264,7 @@ Syntax::Construct - Explicitly state which non-feature constructs are used in th
 
 =head1 VERSION
 
-Version 1.018
+Version 1.019
 
 =head1 SYNOPSIS
 
@@ -290,7 +298,7 @@ them (but see L<Perl::MinimumVersion> on how to extract the
 information from existing code).
 
 Using C<use Syntax::Construct qw( // );> doesn't really change
-anything if you're running Perl 5.10+, but it gives much better error
+anything if you're running Perl 5.010+, but it gives much better error
 messages in older versions:
 
   Unsupported construct //
@@ -329,12 +337,12 @@ Some programmers just use all the I<non-features> their current Perl
 version provides without any notice. This leads to weird error
 messages in older Perl versions.
 
-Some other programmers will place C<use 5.22;> towards the top of the
+Some other programmers will place C<use 5.022;> towards the top of the
 script, even if the only I<non-feature> they use is the C<//> operator
-available in 5.10 already. This prevents users of older versions of
+available in 5.010 already. This prevents users of older versions of
 Perl to run the script, even if it would otherwise be easily possible.
 
-The kindest programmers will add C<use 5.10; # //> towards the top of
+The kindest programmers will add C<use 5.010; # //> towards the top of
 the script. But it means they have to remember or find out what
 version introduced the I<non-feature> they use.
 
@@ -344,9 +352,9 @@ makes it easier for users of older Perl versions to migrate your code
 to their system. And finally, it improves the error messages they get.
 
 Similarly, it's a good practice to keep specifying C<use feature qw{
-postderef };> even if it's a no-op since 5.24: it makes your script
+postderef };> even if it's a no-op since 5.024: it makes your script
 available for people running older Perl versions. The same applies to
-C<use charnames> in 5.16 and later, etc.
+C<use charnames> in 5.016 and later, etc.
 
 =head1 EXPORT
 
@@ -365,7 +373,7 @@ construct was introduced.
 =item removed
 
 Same as C<introduced>, but for removed constructs (e.g. auto-deref in
-5.24).
+5.024).
 
 =back
 
@@ -375,7 +383,7 @@ Same as C<introduced>, but for removed constructs (e.g. auto-deref in
 
 =head3 s-utf8-delimiters-hack
 
-See below. The hack doesn't seem to work in 5.008 and older.
+See below. The hack doesn't seem to work in 5.008 and older. Removed in 5.020.
 
 =head2 5.010
 
@@ -464,10 +472,16 @@ Alias: regex-preserve-match-captures
 
 =head3 lexical-$_
 
-L<perl5100delta/Lexical $_>.
+L<perl5100delta/Lexical $_>. Removed in 5.024.
 
 Alias: lexical-default-variable
 
+=head3 pack<
+
+See L<perl5100delta/Byte-order-modifiers-for-pack()-and-unpack()>
+
+Alias: pack-byte-order-modifiers
+
 =head2 5.012
 
 =head3 package-version
@@ -555,6 +569,7 @@ Alias: regex-restrict-ascii-range
 L<perl5140delta/Array and hash container functions accept
 references>. See also C<push>, C<pop>, C<shift>, C<unshift>,
 C<splice>, C<keys>, C<values>, and C<each> in L<perlfunc>.
+Removed in 5.024.
 
 =head3 ^GLOBAL_PHASE
 
@@ -606,7 +621,7 @@ Alias: attribute-prototype
 =head3 drand48
 
 L<perl5200delta/rand now uses a consistent random number generator>.
-Note that on OpenBSD, Perl 5.20+ uses the system's own C<drand48>
+Note that on OpenBSD, Perl 5.020+ uses the system's own C<drand48>
 unless seeded.
 
 =head3 %slice
@@ -824,11 +839,32 @@ Alias: unicode-identifier-type
 
 L<It is now possible to write \p{Name=...} in perldelta|perldelta/It>
 
+=head2 5.034
+
+=head3 {,n}
+
+L<perldelta/qr/%7B,n%7D/ is now accepted>
+
+Alias: empty-left-quantifier
+
+=head3 0o
+
+L<perldelta/New octal syntax 0oddddd>
+
+Alias: octal-literals
+
+=head3 blanks-in-curlies
+
+L<perldelta/Blanks freely allowed within but adjacent to curly braces>
+
 =for completeness
 =head2 old
 
 =head2 Removed Constructs
 
+Only constructs not mentioned above are listed here, i.e. constructs
+that were introduced before 5.008001.
+
 =head3 ??
 
 Removed in 5.022. See L<perl5220delta/Support for ?PATTERN? without
@@ -836,18 +872,18 @@ explicit operator has been removed>.
 
 =head3 for-qw
 
-Removed in 5.18. See L<perl5180delta/qw(...)-can-no-longer-be-used-as-parentheses>.
+Removed in 5.018. See L<perl5180delta/qw(...)-can-no-longer-be-used-as-parentheses>.
 
 =head3 @_=split
 
-Removed in 5.12, but documented in 5.14. See L<perl5140delta/split()-and-@_>.
+Removed in 5.012, but documented in 5.014. See L<perl5140delta/split()-and-@_>.
 
 Alias: split-populates-@_
 
 =head2 Accepted Features
 
 Some features have been accepted in Perl (C<postderef> and
-C<postderef_qq> in 5.24, C<lexical_subs> in 5.26). In the spirit of
+C<postderef_qq> in 5.024, C<lexical_subs> in 5.026). In the spirit of
 Syntax::Construct, you should still declare them, even if their usage
 has no effect in newer Perl versions to provide meaningful error
 messages to users of older versions.
@@ -869,8 +905,8 @@ see below.
 =head2 Unstable Perl Versions
 
 In development versions of Perl, the removal of constructs is tested
-against the coming stable version -- e.g., 5.23 forbids all the
-removed constructs of 5.24. The behaviour of the module in such
+against the coming stable version -- e.g., 5.023 forbids all the
+removed constructs of 5.024. The behaviour of the module in such
 circumstances might still be, um, unstable.
 
 =head1 SUPPORT
@@ -913,7 +949,7 @@ L<Perl::MinimumVersion>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2013 - 2020 E. Choroba.
+Copyright 2013 - 2021 E. Choroba.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
